```
Usage: vcd gateway services service-certificate add [OPTIONS] <gateway name>

Options:
  --certificate-path <>  certificate file path  [required]
  --private-key-path <>  private key file path  [required]
  --pass-phrase <>       private key passphrase
  --description <>       description
  -h, --help             Show this message and exit.

```
